all_image_handler library

Classes

AllImageConfig
Global configuration for AllImageHandler widgets.
AllImageController
A controller used to manage and reload an AllImageHandler widget.
AllImageError
AllImageHandler
A versatile Flutter widget that automatically detects and renders images from various sources (network, asset, file, memory, SVG) with support for caching, shimmer loading, retry, error handling, and hero animation.
AllImageOptions
AllImageShimmer
AllImageUtils